@@ -111,7 +111,7 @@ void MainWindow::resizeEvent(QResizeEvent *event){
   from the National Weather Service containing an XML file.
   */
 void MainWindow::setDomDocument(QString *reply){
-    QFile file("tmp.xml");
+    QFile file("/tmp/qtweather.xml");
 
     if (!file.open(QIODevice::WriteOnly)){
         cout << "could not open" << endl;
